# Yamcs Client Library for Python
[![Website](https://img.shields.io/website/http/shields.io.svg?label=docs)](https://www.yamcs.org/yamcs-python/yamcs-client)
[![Build Status](https://travis-ci.org/yamcs/yamcs-python.svg?branch=master)](https://travis-ci.org/yamcs/yamcs-python)
[![PyPI](https://img.shields.io/pypi/v/yamcs-client.svg)](https://pypi.python.org/pypi/yamcs-client)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/yamcs-client.svg)](https://pypi.python.org/pypi/yamcs-client/)


## Features

* MDB retrieval
* Telemetry updates
* Command History updates
* Alarm updates
* Event updates
* Archive retrieval
* Histogram retrieval


## Installation

The easiest way to install is via pip

    pip install yamcs-client


## Documentation

All available operations are documented at https://www.yamcs.org/yamcs-python/yamcs-client


## License

LGPL-3.0. See [LICENSE](https://github.com/yamcs/yamcs-python/blob/master/LICENSE)
